@@ -1,4 +1,4 @@
-from bender.split_strategy.split_strategy import RandomRatioSplitter, SortedRatioSplitter
+from bender.split_strategy.split_strategy import RandomRatioSplitter, SortedRatioSplitter, UniformSplitRatio
 
 
 class SplitStrategies:
@@ -9,3 +9,7 @@ class SplitStrategies:
     @staticmethod
     def sorted_ratio(sort_key: str, ratio: float) -> SortedRatioSplitter:
         return SortedRatioSplitter(min(max(ratio, 0), 1), sort_key)
+
+    @staticmethod
+    def uniform_ratio(feature: str, ratio: float) -> UniformSplitRatio:
+        return UniformSplitRatio(ratio, feature)
